/**
 * \file PTC_Task.hh
 * \author Scott F. H. Kaplan -- sfkaplan@cs.amherst.edu
 * \date January 2003
 * \brief A Task subclass designed for Per_Task_Consumers.
 **/



// ===================================================================
// Avoid multiple inclusion.
#if !defined (_PTC_TASK_HH)
#define _PTC_TASK_HH
// ===================================================================



// ===================================================================
// INCLUDES

#include "Per_Task_Writer.hh"
#include "Task.hh"
// ===================================================================



// ===================================================================
// CLASS DEFINITION

/**
 * \brief A Task subclass designed for use with Per_Task_Consumer.
 *
 * An extention to the Task class such that it also stores a pointer
 * to a Per_Task_Writer, used by the Per_Task_Consumer to handle the
 * reference stream of each task.
 **/
class PTC_Task : public Task {

public:

  /**
   * \brief The constructor.
   *
   * Initialize a task by zeroing its fields.
   **/
  PTC_Task () {
    writer = NULL;
  }

public: // DATA MEMBERS

  /** \brief A pointer to the output stream writer for this task. */
  Per_Task_Writer* writer;

}; // class PTC_Task
// ===================================================================



// ===================================================================
#endif // _PTC_TASK_HH
// ===================================================================
