/**
 * \file Process.hh
 * \author Scott F. H. Kaplan -- sfkaplan@cs.amherst.edu
 * \date January 2003
 * \brief A structure to store data about a process.
 **/



// ===================================================================
// Avoid multiple inclusion.
#if !defined (_PROCESS_HH)
#define _PROCESS_HH
// ===================================================================



// ===================================================================
// INCLUDES

#include "types-and-constants.hh"
// ===================================================================



// ===================================================================
// FORWARD DECLARATION

class Task;
// ===================================================================



// ===================================================================
// CLASS DEFINITION

/**
 * \brief A structure to store data about a process.
 * \see Task
 *
 * Processes are simply collections of tasks, where a task is really a
 * kernel-level thread.  Note that we make data members public for
 * simplicity of access, violating good OO programming guidelines.
 **/
class Process {

public:

  /**
   * \brief The constructor.
   *
   * Initialize a process by zeroing its fields.
   **/
  Process () {
    process_ID = 0;
    context_ID = 0;
    virtual_to_canonical_map = NULL;
    image_file_ID.inode_ID = 0;
    image_file_ID.major = 0;
    image_file_ID.minor = 0;
  }

public: // DATA MEMBERS

  /** \brief A unique process number. */
  process_ID_t process_ID;

  /** \brief A list of tasks that compose the threads of the
   *         process. */
  list<Task*> task_list;

  /** \brief The context associated with the process. */
  context_ID_t context_ID;

  /** \brief A map from virtual to canonical pages. */
  virtual_to_canonical_map_t* virtual_to_canonical_map;

  /** \brief The file ID of the current executable image. */
  file_ID_s image_file_ID;

  /**\brief The path used to name the current executable image. */
  char image_pathname[BUFFER_SIZE];

}; // class Process
// ===================================================================



// ===================================================================
#endif // _PROCESS_HH
// ===================================================================
