/**
 * \file Reference_Reader.cc
 * \author Scott F. H. Kaplan <sfkaplan@cs.amherst.edu>
 * \date January 2003
 * \brief Header of base class for reading and parsing reference
 * traces.
 *
 * A class that defines the interface for reading and parsing a
 * reference trace.  This is an ABSTRACT CLASS: It does not define the
 * read() method.  By defining this method, a subclass actually read
 * and parse some specific reference trace format and place the needed
 * results into the data structure that read() accepts as an
 * argument.
 **/



// ===================================================================
// INCLUDES

#include <assert.h>
#include <stdio.h>
#include <stdlib.h>
#include <sys/errno.h>
#include "Reference_Reader.hh"
#include "types-and-constants.hh"
// ===================================================================



// ===================================================================
Reference_Reader::Reference_Reader
(const char* const reference_trace_pathname) {

  // Attempt to open the trace file.
  reference_stream = fopen(reference_trace_pathname, "r");

  // Did the reference trace open correctly?
  if (reference_stream == NULL) {

    // No.  Emit the error and exit.
    perror("Failed opening reference trace");
    exit(1);

  }
} // Reference_Reader
// ===================================================================



// ===================================================================
Reference_Reader::~Reference_Reader () {

  // Was the reference stream opened?  (A subclass is not required to
  // use this data member.)
  if (reference_stream != NULL) {

    // Yes.  Attempt to close it, ensuring success.
    int reference_result = fclose(reference_stream);
    if (reference_result == EOF) {
      perror("Failed closing reference trace");
      exit(1);
    }

  }
} // ~Consumer
// ===================================================================
