/**
 * \file Task.cc
 * \author Scott F. H. Kaplan -- sfkaplan@cs.amherst.edu
 * \date January 2003
 * \brief Methods to keep information about a task up-to-date.
 **/



// ===================================================================
// INCLUDES

#include "Task.hh"
// ===================================================================



// ===================================================================
Task::Task () {

  // Initialize all of the data members to zero/null.
  task_ID = 0;
  process = NULL;
  parent_task = NULL;
  virtual_cycle_time = 0;
  virtual_instruction_time = 0;
  virtual_reference_time = 0;
  last_system_cycle_time = 0;
  last_system_instruction_time = 0;
  last_system_reference_time = 0;

} // Task::Task
// ===================================================================



// ===================================================================
void
Task::mark_quanta_start (const timestamp_t system_cycle_time,
			 const timestamp_t system_instruction_time,
			 const timestamp_t system_reference_time) {

  // Bump up the observed system time, but not the virtual time, as
  // this is the beginning of a quanta, and time passed since the last
  // observed system time was due to some other task.
  last_system_cycle_time = system_cycle_time;
  last_system_instruction_time = system_instruction_time;
  last_system_reference_time = system_reference_time;

} // Task::mark_quanta_start
// ===================================================================



// ===================================================================
void
Task::mark_time (const timestamp_t system_cycle_time,
		 const timestamp_t system_instruction_time,
		 const timestamp_t system_reference_time) {

  // How much time has passed since the last call to this method?
  timestamp_t cycle_time_passed =
    system_cycle_time - last_system_cycle_time;
  timestamp_t instruction_time_passed =
    system_instruction_time - last_system_instruction_time;
  timestamp_t reference_time_passed =
    system_reference_time - last_system_reference_time;

  // Update the virtual time that has passed for this task, as this
  // method is called only when this task is scheduled.
  virtual_cycle_time += cycle_time_passed;
  virtual_instruction_time += instruction_time_passed;
  virtual_reference_time += reference_time_passed;

  // Bump up the observed system time.
  last_system_cycle_time = system_cycle_time;
  last_system_instruction_time = system_instruction_time;
  last_system_reference_time = system_reference_time;

} // Task::mark_time
// ===================================================================
